@@ -115,7 +115,7 @@ def plot_pr_curve(network, X_test: np.ndarray, y_test: np.ndarray,
     plt.xlabel("Recall")
     plt.ylabel("Precision")
     plt.title("PR Curve")
-    plt.gca().set_aspect("equal", adjustable='box')
+    plt.gca().set_aspect("equal", adjustable="box")
     plt.legend(loc="lower left")
     plt.grid(True)
     plt.show()
@@ -158,7 +158,7 @@ def plot_roc_curve(network, X_test: np.ndarray, y_test: np.ndarray,
     plt.xlabel("False Positive Rate")
     plt.ylabel("True Positive Rate")
     plt.title("ROC Curve")
-    plt.gca().set_aspect('equal', adjustable='box')
+    plt.gca().set_aspect("equal", adjustable="box")
     plt.legend(loc="lower right")
     plt.grid(True)
     plt.show()
